package com.muyu.common.core.enums;

import java.util.Arrays;

/**
 * @Author：yang
 * @Package：com.muyu.common.core.enums
 * @Project：cloud-common-core
 * @name：SysPayType
 * @Date：2024/8/9 10:33
 */
public enum SysPayType {
    ALI_PAY("aliPay","支付宝"),
    WECHAT_PAY("wechatPay","微信支付"),
    JD_PAY("jdPay","京东支付"),
            ;

    private final String code;
    private final String info;

    SysPayType(String code, String info) {
        this.code = code;
        this.info = info;
    }

    public String getCode() {
        return code;
    }

    public String getInfo() {
        return info;
    }

    public static boolean isCode(String code){
        return Arrays.stream(values())
                .map(SysPayType::getCode)
                .anyMatch(s -> s.equals(code));//传cou
    }

    /**
     * 通过code获取支付渠道
     * @param code code code编码
     * @return 支付渠道
     */
    public static String getInifByCode(String code){
       return Arrays.stream(values())
                .filter(s->s.getCode().equals(code))
                .findFirst()
                .map(SysPayType::getInfo)
                .orElseGet(() -> "-");
    }
}
